@@ -1,13 +1,13 @@
 package Log::Any::For::Package;
 
-our $DATE = '2015-04-25'; # DATE
-our $VERSION = '0.25'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.26'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
 use experimental 'smartmatch';
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Data::Clean::JSON;
 use Package::MoreUtil qw(package_exists list_package_contents
@@ -373,7 +373,7 @@ Log::Any::For::Package - Add logging to package
 
 =head1 VERSION
 
-This document describes version 0.25 of Log::Any::For::Package (from Perl distribution Log-Any-For-Class), released on 2015-04-25.
+This document describes version 0.26 of Log::Any::For::Package (from Perl distribution Log-Any-For-Class), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -451,8 +451,9 @@ L<Log::Any::For::DBI>, L<Log::Any::For::LWP>.
 
 =head2 add_logging_to_package(%args) -> any
 
-Add logging to package.
+{en_US Add logging to package}.
 
+{en_US 
 Logging will be done using Log::Any.
 
 Currently this function adds logging around function calls, e.g.:
@@ -461,48 +462,59 @@ Currently this function adds logging around function calls, e.g.:
  <--- Package::func() = RESULT
  ...
 
+}
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
 =item * B<filter_subs> => I<re|code>
 
-Filter subroutines to add logging to.
+{en_US Filter subroutines to add logging to}.
 
+{en_US 
 The default is to read from environment C<LOG_PACKAGE_INCLUDE_SUB_RE> and
 C<LOG_PACKAGE_EXCLUDE_SUB_RE> (these should contain regex that will be matched
 against fully-qualified subroutine/method name), or, if those environment are
 undefined, add logging to all non-private subroutines (private subroutines are
 those prefixed by C<_>). For example.
+}
 
 =item * B<import_hook> => I<bool> (default: 0)
 
-Whether to install import (@INC) hook instead.
+{en_US Whether to install import (@INC) hook instead}.
 
+{en_US 
 If this setting is true, then instead of installing logging to all existing
 packages, an @INC import hook will be installed instead so that subsequent
 modules that are loaded and that match C<packages> will be logged. So to log all
 subsequent loaded modules, you can set C<packages> to C<['.*']>.
+}
 
 =item * B<logger_args> => I<any>
 
-Pass arguments to logger.
+{en_US Pass arguments to logger}.
 
+{en_US 
 This allows passing arguments to logger routine.
+}
 
 =item * B<packages>* => I<array[str]>
 
-Packages to add logging to.
+{en_US Packages to add logging to}.
 
+{en_US 
 Each element can be the name of a package or a regex pattern (any non-valid
 package name will be regarded as a regex). If the package is (comes from) a
 module, the module must already be loaded. This function will not load modules
 for you.
+}
 
 =item * B<postcall_logger> => I<code>
 
-Supply custom postcall logger.
+{en_US Supply custom postcall logger}.
 
+{en_US 
 Just like C<precall_logger>, but code will be called after subroutine/method is
 called. Code will be given a hashref argument \%args containing these keys:
 C<args> (arrayref, a shallow copy of the original @_), C<orig> (coderef, the
@@ -511,11 +523,13 @@ subroutine/method name), C<result> (arrayref, the subroutine/method result),
 C<logger_args> (arguments given when adding logging).
 
 You can use this mechanism to customize logging.
+}
 
 =item * B<precall_logger> => I<code>
 
-Supply custom precall logger.
+{en_US Supply custom precall logger}.
 
+{en_US 
 Code will be called when logging subroutine/method call. Code will be given a
 hashref argument \%args containing these keys: C<args> (arrayref, a shallow copy
 of the original @_), C<orig> (coderef, the original subroutine/method), C<name>
@@ -559,6 +573,7 @@ be supplied via environment C<LOG_SUB_ARGS>.
 
 Whether to display subroutine result when logging subroutine exit. The default
 can also be set via environment C<LOG_SUB_RESULT>.
+}
 
 =back
 
